Query financial data directly.

# Description
    
A wrapper on the Fidap API that allows users to easily query financial data.

# Installation
 
## Normal installation

```bash
pip install fidap
```

## Development installation

```bash
git clone https://github.com/fidapco/fidap-python.git
cd fidap-python
pip install --editable .
```